==> seedsui-react-5.7.17.tgz: package/lib/DatePicker/Modal/Utils.js <==
import locale from "./../../locale";

// eslint-disable-next-line
export default {
  // 获取默认值, 用于实例化日期
  getDefaults: function getDefaults(value) {
    var defaultValue = value;
    if (defaultValue instanceof Date === false) {
      defaultValue = new Date();
    }
    var defaultDay = defaultValue.getDate();
    defaultDay = defaultDay < 10 ? '0' + defaultDay : defaultDay;
    var defaultHour = defaultValue.getHours();
    defaultHour = defaultHour < 10 ? '0' + defaultHour : defaultHour;
    var defaultMinute = defaultValue.getMinutes();
    defaultMinute = defaultMinute < 10 ? '0' + defaultMinute : defaultMinute;
    return {
      year: defaultValue.getFullYear(),
      quarter: defaultValue.quarter(),
      month: defaultValue.month(),
      day: defaultDay,
      hour: defaultHour,
      minute: defaultMinute
    };
  },
  // 数据
  getData: function getData(data) {
    // 自定义数据
    var yearsData = null;
    var quartersData = null;
    var monthsData = null;
    var daysData = null;
    var hoursData = null;
    var minutesData = null;
    if (data) {
      if (data.year) {
        yearsData = data.year.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_year') // 年
          };
        });
      }

      if (data.quarter) {
        quartersData = data.quarter.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_quarter') // 季
          };
        });
      }

      if (data.month) {
        monthsData = data.month.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_month') // 月
          };
        });
      }

      if (data.day) {
        daysData = data.day.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_date') // 日
          };
        });
      }

      if (data.hour) {
        hoursData = data.hour.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_hour') // 时
          };
        });
      }

      if (data.minute) {
        minutesData = data.minute.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_minute') // 分
          };
        });
      }
    }

    return {
      yearsData: yearsData,
      quartersData: quartersData,
      monthsData: monthsData,
      daysData: daysData,
      hoursData: hoursData,
      minutesData: minutesData
    };
  },
  // 格式化日期
  formatDate: function formatDate(date, type) {
    if (type === 'year') {
      return date.format('YYYY');
    } else if (type === 'quarter') {
      return date.format('YYYY-Q');
    } else if (type === 'month') {
      return date.format('YYYY-MM');
    } else if (type === 'date') {
      return date.format('YYYY-MM-DD');
    } else if (type === 'datetime') {
      return date.format('YYYY-MM-DD hh:mm');
    } else if (type === 'time') {
      return date.format('hh:mm');
    }
  }
};

==> seedsui-react-5.7.20.tgz: package/lib/DatePicker/Modal/Utils.js <==
import locale from "./../../locale";

// eslint-disable-next-line
export default {
  // 获取默认值, 用于实例化日期
  getDefaults: function getDefaults(value, defaultPickerValue) {
    var defaultValue = value;
    if (Object.isDate(defaultValue) === false) {
      defaultValue = Object.isDate(defaultPickerValue) ? defaultPickerValue : new Date();
    }
    var defaultDay = defaultValue.getDate();
    defaultDay = defaultDay < 10 ? '0' + defaultDay : defaultDay;
    var defaultHour = defaultValue.getHours();
    defaultHour = defaultHour < 10 ? '0' + defaultHour : defaultHour;
    var defaultMinute = defaultValue.getMinutes();
    defaultMinute = defaultMinute < 10 ? '0' + defaultMinute : defaultMinute;
    return {
      year: defaultValue.getFullYear(),
      quarter: defaultValue.quarter(),
      month: defaultValue.month(),
      day: defaultDay,
      hour: defaultHour,
      minute: defaultMinute
    };
  },
  // 数据
  getData: function getData(data) {
    // 自定义数据
    var yearsData = null;
    var quartersData = null;
    var monthsData = null;
    var daysData = null;
    var hoursData = null;
    var minutesData = null;
    if (data) {
      if (data.year) {
        yearsData = data.year.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_year') // 年
          };
        });
      }

      if (data.quarter) {
        quartersData = data.quarter.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_quarter') // 季
          };
        });
      }

      if (data.month) {
        monthsData = data.month.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_month') // 月
          };
        });
      }

      if (data.day) {
        daysData = data.day.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_date') // 日
          };
        });
      }

      if (data.hour) {
        hoursData = data.hour.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_hour') // 时
          };
        });
      }

      if (data.minute) {
        minutesData = data.minute.map(function (n) {
          return {
            id: '' + n,
            name: '' + n + locale('', 'picker_unit_minute') // 分
          };
        });
      }
    }

    return {
      yearsData: yearsData,
      quartersData: quartersData,
      monthsData: monthsData,
      daysData: daysData,
      hoursData: hoursData,
      minutesData: minutesData
    };
  },
  // 格式化日期
  formatDate: function formatDate(date, type) {
    if (type === 'year') {
      return date.format('YYYY');
    } else if (type === 'quarter') {
      return date.format('YYYY-Q');
    } else if (type === 'month') {
      return date.format('YYYY-MM');
    } else if (type === 'date') {
      return date.format('YYYY-MM-DD');
    } else if (type === 'datetime') {
      return date.format('YYYY-MM-DD hh:mm');
    } else if (type === 'time') {
      return date.format('hh:mm');
    }
  }
};
